@@ -27,7 +27,7 @@ import tomlkit.exceptions
 from pdm import termui
 from pdm.__version__ import __version__
 from pdm.cli.options import ignore_python_option, no_cache_option, non_interactive_option, pep582_option, verbose_option
-from pdm.cli.utils import ArgumentParser, ErrorArgumentParser
+from pdm.cli.utils import ArgumentParser, ErrorArgumentParser, format_similar_command
 from pdm.compat import importlib_metadata
 from pdm.exceptions import PdmArgumentError, PdmUsageError
 from pdm.installers import InstallManager
@@ -77,6 +77,7 @@ class Core:
         self.ui = termui.UI(exit_stack=self.exit_stack)
         self.state = State()
         self.exit_stack.callback(setattr, self, "config_settings", None)
+        self.commands: list[str] = []
         self.init_parser()
         self.load_plugins()
 
@@ -256,7 +257,9 @@ class Core:
 
         project = self.ensure_project(options, obj)
         if root_script and root_script not in project.scripts:
-            self.parser.error(f"Script unknown: {root_script}")
+            message = format_similar_command(root_script, self.commands, list(project.scripts.keys()))
+            message = termui.style(message)
+            self.parser.error(message)
 
         try:
             self.handle(project, options)
@@ -289,6 +292,7 @@ class Core:
                 is used
         """
         assert self.subparsers
+        self.commands.append(name or command.name or "")
         command.register_to(self.subparsers, name)
 
     @staticmethod
@@ -311,7 +315,15 @@ class Core:
 
         base = str(project.root / ".pdm-plugins")
         replace_vars = {"base": base, "platbase": base}
-        scheme = "nt" if os.name == "nt" else "posix_prefix"
+
+        scheme_names = sysconfig.get_scheme_names()
+        if (sys.platform == "darwin" and "osx_framework_library" in scheme_names) or sys.platform == "linux":
+            scheme = "posix_prefix"
+        # sysconfig._get_default_scheme is a private function in 3.8 & 3.9
+        elif sys.version_info < (3, 10):
+            scheme = "nt" if os.name == "nt" else "posix_prefix"
+        else:
+            scheme = sysconfig.get_default_scheme()
         purelib = sysconfig.get_path("purelib", scheme, replace_vars)
         scripts = sysconfig.get_path("scripts", scheme, replace_vars)
         site.addsitedir(purelib)
